==> agora_chat_sdk-1.0.5.tar.gz: lib/src/models/chat_push_configs.dart <==
import 'package:flutter/services.dart';

import '../internal/chat_method_keys.dart';
import '../tools/chat_extension.dart';
import 'chat_enums.dart';
import 'chat_error.dart';
import '../chat_push_manager.dart';

/// The push configuration class.
class ChatPushConfigs {
  ChatPushConfigs._private({
    this.displayStyle = DisplayStyle.Simple,
    this.noDisturb = false,
    this.noDisturbStartHour = -1,
    this.noDisturbEndHour = -1,
  });

  ///
  /// The display type of push notifications.
  ///
  final DisplayStyle displayStyle;

  ///
  /// Whether to enable the do-not-disturb mode for push notifications.
  /// - `true`: Yes.
  /// - `false`: No.
  ///  Sets it by {@link ChatPushManager#disableOfflinePush(int, int)}.
  ///
  final bool noDisturb;

  ///
  /// The start hour of the do-not-disturb mode for push notifications.
  ///
  final int noDisturbStartHour;

  ///
  /// The end hour of the do-not-disturb mode for push notifications.
  ///
  final int noDisturbEndHour;

  // ignore: unused_field
  DisplayStyle? _displayStyle;
  // ignore: unused_field
  bool? _noDisturb;
  // ignore: unused_field
  int? _noDisturbStartHour;
  // ignore: unused_field
  int? _noDisturbEndHour;
  // ignore: unused_field
  List<String>? _noDisturbGroups = [];

  /// @nodoc
  factory ChatPushConfigs.fromJson(Map map) {
    return ChatPushConfigs._private(
      displayStyle:
          map['pushStyle'] == 0 ? DisplayStyle.Simple : DisplayStyle.Summary,
      noDisturb: map.boolValue('noDisturb'),
      noDisturbStartHour: map['noDisturbStartHour'],
      noDisturbEndHour: map['noDisturbEndHour'],
    );
  }
}

/// @nodoc
extension ChatPushConfigsExtension on ChatPushConfigs {
  // channel的命名与pushManager中的channel一致，本质上还是一个channel。
  static const MethodChannel _channel =
      const MethodChannel('com.chat.im/chat_push_manager', JSONMethodCodec());

  @Deprecated(
      "Switch to using ChatPushManager#enableOfflinePush and ChatPushManager#disableOfflinePush instead")
  Future<void> setNoDisturb(
    bool isNoDisturb, {
    int startTime = 0,
    int endTime = 24,
  }) async {
    if (startTime < 0) startTime = 0;
    if (endTime > 24) endTime = 24;
    Map req = {
      'noDisturb': isNoDisturb,
      'startTime': startTime,
      'endTime': endTime
    };
    Map result = await _channel.invokeMethod("imPushNoDisturb", req);
    try {
      ChatError.hasErrorFromResult(result);
      bool success = result.boolValue("imPushNoDisturb");
      if (success) {
        _noDisturb = isNoDisturb;
        _noDisturbStartHour = startTime;
        _noDisturbEndHour = endTime;
      }
    } on ChatError catch (e) {
      throw e;
    }
  }

  @Deprecated("Switch to using ChatPushManager#updatePushDisplayStyle instead")
  Future<void> setPushStyle(EMPushStyle pushStyle) async {
    Map req = {'pushStyle': pushStyle == EMPushStyle.Simple ? 0 : 1};
    Map result =
        await _channel.invokeMethod(ChatMethodKeys.updateImPushStyle, req);
    try {
      ChatError.hasErrorFromResult(result);
    } on ChatError catch (e) {
      throw e;
    }
  }

  @Deprecated("Switch to using ChatPushManager#updatePushServiceForGroup instead")
  Future<void> setGroupToDisturb(
    String groupId,
    bool isNoDisturb,
  ) async {
    Map req = {'noDisturb': isNoDisturb, 'group_id': groupId};
    Map result =
        await _channel.invokeMethod(ChatMethodKeys.updateGroupPushService, req);
    try {
      ChatError.hasErrorFromResult(result);
    } on ChatError catch (e) {
      throw e;
    }
  }

  @Deprecated("Switch to using ChatPushManager#getNoPushGroups instead")
  Future<List<String>> noDisturbGroupsFromServer() async {
    Map result = await _channel.invokeMethod("getNoDisturbGroups");
    try {
      ChatError.hasErrorFromResult(result);
      List<String> list = [];
      result["getNoDisturbGroups"]?.forEach((element) {
        if (element is String) {
          list.add(element);
        }
      });
      return list;
    } on ChatError catch (e) {
      throw e;
    }
  }
}

==> agora_chat_sdk-1.0.8.tar.gz: lib/src/models/chat_push_configs.dart <==
import '../internal/inner_headers.dart';

/// The push configuration class.
class ChatPushConfigs {
  ChatPushConfigs._private({
    this.displayStyle = DisplayStyle.Simple,
    this.displayName,
    this.noDisturb = false,
    this.noDisturbStartHour = -1,
    this.noDisturbEndHour = -1,
  });

  ///
  /// The display type of push notifications.
  ///
  final DisplayStyle displayStyle;

  ///
  /// The user's nickname to be displayed in the notification.
  ///
  final String? displayName;

  ///
  /// Whether to enable the do-not-disturb mode for push notifications.
  /// - `true`: Yes.
  /// - `false`: No.
  ///  Sets it by [ChatPushManager.disableOfflinePush].
  ///
  @Deprecated(
      "Use ChatSilentModeResult property remindType, expireTimestamp and silentModeTime determine whether to enable")
  final bool noDisturb;

  ///
  /// The start hour of the do-not-disturb mode for push notifications.
  ///
  @Deprecated("Use ChatSilentModeResult property startTime instead")
  final int noDisturbStartHour;

  ///
  /// The end hour of the do-not-disturb mode for push notifications.
  ///
  @Deprecated("Use ChatSilentModeResult property endTime instead")
  final int noDisturbEndHour;

  /// @nodoc
  factory ChatPushConfigs.fromJson(Map map) {
    return ChatPushConfigs._private(
      displayStyle:
          map['pushStyle'] == 0 ? DisplayStyle.Simple : DisplayStyle.Summary,
      noDisturb: map.boolValue('noDisturb'),
      noDisturbStartHour: map['noDisturbStartHour'],
      noDisturbEndHour: map['noDisturbEndHour'],
      displayName: map["displayName"],
    );
  }
}
